aboutsummaryrefslogtreecommitdiff
path: root/gcc/c-parse.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/c-parse.c')
-rw-r--r--gcc/c-parse.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/gcc/c-parse.c b/gcc/c-parse.c
index 9c71df9..a00ba33 100644
--- a/gcc/c-parse.c
+++ b/gcc/c-parse.c
@@ -1,6 +1,7 @@
/* A Bison parser, made from c-parse.y
- by GNU Bison version 1.28 */
+ by GNU Bison version 1.27
+ */
#define YYBISON 1 /* Identify Bison output. */
@@ -1275,7 +1276,7 @@ static const short yycheck[] = { 38,
};
/* -*-C-*- Note some compilers choke on comments on `#line' lines. */
#line 3 "/usr/lib/bison.simple"
/* This file comes from bison-1.28. */
/* Skeleton output parser for bison,
Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -1488,7 +1489,7 @@ __yy_memcpy (char *to, char *from, unsigned int count)
#endif
#endif
-#line 217 "/usr/lib/bison.simple"
+#line 216 "/usr/lib/bison.simple"
/* The user can define YYPARSE_PARAM as the name of an argument to be passed
into yyparse. The argument should have type void *.
@@ -3835,7 +3836,7 @@ case 407:
break;}
}
/* the action file gets copied in in place of this dollarsign */
-#line 543 "/usr/lib/bison.simple"
+#line 542 "/usr/lib/bison.simple"
yyvsp -= yylen;
yyssp -= yylen;
@@ -1275,7 +1276,7 @@ static const short yycheck[] = { 38,
/* -*-C-*- Note some compilers choke on comments on `#line' lines. */
#line 3 "/usr/lib/bison.simple"
-/* This file comes from bison-1.28. */
+/* This file comes from bison-1.27. */
/* Skeleton output parser for bison,
Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.